# OperationJobStatus


## Enum

* `PENDING` (value: `'Pending'`)

* `PROCESSING` (value: `'Processing'`)

* `FAILED` (value: `'Failed'`)

* `COMPLETED` (value: `'Completed'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


